# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/cocktail.svg' card_color='#0080b0' width='50' height='50' style='vertical-align:bottom'/> Cocktails
Get help mixing drinks.

## About 
Let OVOS help you mix better and more fun drinks and cocktails. When asked the assistant provides ingredients and mixing instructions for various drinks. The skill uses the fabulous [theCocktailDB](https://thecocktaildb.com/). 

## Examples 
* "how do I mix a Moscow Mule"
* "how do I make a daiquiri"

## Credits 
@forslund

## Category
**Information**

## Tags
#drinks
#recipies
#cocktails

